@@ -11,7 +11,6 @@
 # limitations under the License.
 
 import contextlib
-import json
 import logging
 import queue
 import shutil
@@ -141,6 +140,7 @@ def run_build():
     kolla.setup_working_dir()
     kolla.find_dockerfiles()
     kolla.create_dockerfiles()
+    kolla.create_patch_files()
     kolla.build_image_list()
     kolla.find_parents()
     kolla.filter_images()
@@ -204,8 +204,6 @@ def run_build():
             raise
 
     if conf.summary:
-        results = kolla.summary()
-        if conf.format == 'json':
-            print(json.dumps(results))
+        kolla.summary()
     kolla.cleanup()
     return kolla.get_image_statuses()
