@@ -81,12 +81,10 @@ class TasksTest(base.TestCase):
     @mock.patch(engine_client)
     def test_push_image(self, mock_client):
         self.engine_client = mock_client
-        mock_client().api._auth_configs = {}
         pusher = tasks.PushTask(self.conf, self.image)
         pusher.run()
         mock_client().images.push.assert_called_once_with(
-            self.image.canonical_name,
-            decode=True, stream=True, auth_config={})
+            self.image.canonical_name, decode=True, stream=True)
         self.assertTrue(pusher.success)
 
     @mock.patch.dict(os.environ, clear=True)
@@ -94,13 +92,11 @@ class TasksTest(base.TestCase):
     def test_push_image_failure(self, mock_client):
         """failure on connecting Docker API"""
         self.engine_client = mock_client
-        mock_client().api._auth_configs = {}
         mock_client().images.push.side_effect = Exception
         pusher = tasks.PushTask(self.conf, self.image)
         pusher.run()
         mock_client().images.push.assert_called_once_with(
-            self.image.canonical_name,
-            decode=True, stream=True, auth_config={})
+            self.image.canonical_name, decode=True, stream=True)
         self.assertFalse(pusher.success)
         self.assertEqual(utils.Status.PUSH_ERROR, self.image.status)
 
@@ -109,13 +105,11 @@ class TasksTest(base.TestCase):
     def test_push_image_failure_retry(self, mock_client):
         """failure on connecting Docker API, success on retry"""
         self.engine_client = mock_client
-        mock_client().api._auth_configs = {}
         mock_client().images.push.side_effect = [Exception, []]
         pusher = tasks.PushTask(self.conf, self.image)
         pusher.run()
         mock_client().images.push.assert_called_once_with(
-            self.image.canonical_name,
-            decode=True, stream=True, auth_config={})
+            self.image.canonical_name, decode=True, stream=True)
         self.assertFalse(pusher.success)
         self.assertEqual(utils.Status.PUSH_ERROR, self.image.status)
 
@@ -131,14 +125,12 @@ class TasksTest(base.TestCase):
     def test_push_image_failure_error(self, mock_client):
         """Docker connected, failure to push"""
         self.engine_client = mock_client
-        mock_client().api._auth_configs = {}
         mock_client().images.push.return_value = [{'errorDetail': {'message':
                                                   'mock push fail'}}]
         pusher = tasks.PushTask(self.conf, self.image)
         pusher.run()
         mock_client().images.push.assert_called_once_with(
-            self.image.canonical_name,
-            decode=True, stream=True, auth_config={})
+            self.image.canonical_name, decode=True, stream=True)
         self.assertFalse(pusher.success)
         self.assertEqual(utils.Status.PUSH_ERROR, self.image.status)
 
@@ -147,14 +139,12 @@ class TasksTest(base.TestCase):
     def test_push_image_failure_error_retry(self, mock_client):
         """Docker connected, failure to push, success on retry"""
         self.engine_client = mock_client
-        mock_client().api._auth_configs = {}
         mock_client().images.push.return_value = [{'errorDetail': {'message':
                                                   'mock push fail'}}]
         pusher = tasks.PushTask(self.conf, self.image)
         pusher.run()
         mock_client().images.push.assert_called_once_with(
-            self.image.canonical_name,
-            decode=True, stream=True, auth_config={})
+            self.image.canonical_name, decode=True, stream=True)
         self.assertFalse(pusher.success)
         self.assertEqual(utils.Status.PUSH_ERROR, self.image.status)
 
@@ -671,24 +661,6 @@ class KollaWorkerTest(base.TestCase):
         kolla = build.KollaWorker(self.conf)
         self.assertEqual(2, len(kolla.rpm_setup))
 
-    def test_build_distro_python_version_debian(self):
-        """check distro_python_version for Debian"""
-        self.conf.set_override('base', 'debian')
-        kolla = build.KollaWorker(self.conf)
-        self.assertEqual('3.11', kolla.distro_python_version)
-
-    def test_build_distro_python_version_ubuntu(self):
-        """check distro_python_version for Ubuntu"""
-        self.conf.set_override('base', 'ubuntu')
-        kolla = build.KollaWorker(self.conf)
-        self.assertEqual('3.10', kolla.distro_python_version)
-
-    def test_build_distro_python_version_centos(self):
-        """check distro_python_version for CentOS Stream 9"""
-        self.conf.set_override('base', 'centos')
-        kolla = build.KollaWorker(self.conf)
-        self.assertEqual('3.9', kolla.distro_python_version)
-
     def test_build_distro_package_manager(self):
         """check distro_package_manager conf value is taken"""
         self.conf.set_override('distro_package_manager', 'foo')
